@@ -467,8 +467,8 @@ Greeks_UI <- function() {
               dividend_yield = dividend_yield,
               payoff = payoff,
               greek = greek
-            ) |> as_tibble() |>
-            add_column(x = x) |>
+            ) %>% as_tibble() %>%
+            add_column(x = x) %>%
             pivot_longer(cols = -x,
                          names_to = "Greek",
                          values_to = "Value")
