@@ -1,10 +1,10 @@
 test_that("Malliavin_European_Greeks is correct", {
 
-  number_of_runs <- 30
+  number_of_runs <- 6
 
   Greeks <- c("fair_value", "delta", "vega", "theta", "rho", "gamma")
 
-  error <- numeric(number_of_runs)
+  error <- matrix(nrow = number_of_runs, ncol = length(Greeks))
 
   set.seed(42)
 
@@ -19,11 +19,9 @@ test_that("Malliavin_European_Greeks is correct", {
     time_to_maturity <- runif(1, 0.2, 6)
     volatility <- runif(1, 0.01, 1)
     model <- "Black_Scholes"
-    payoff <- sample(
-      c("call", "put", "cash_or_nothing_call", "cash_or_nothing_put",
-        "asset_or_nothing_put"), 1)
+    payoff <- c("call", "put", "cash_or_nothing_call", "cash_or_nothing_put",
+                "asset_or_nothing_call", "asset_or_nothing_put")[i]
     antithetic <- sample(c(TRUE, FALSE), 1)
-    greek <- sample(Greeks, 1)
 
     Malliavin_Value <-
       Malliavin_European_Greeks(
@@ -33,7 +31,7 @@ test_that("Malliavin_European_Greeks is correct", {
         time_to_maturity = time_to_maturity,
         volatility = volatility,
         payoff = payoff,
-        greek = greek,
+        greek = Greeks,
         paths = 2000000,
         antithetic = antithetic
       )
@@ -47,16 +45,21 @@ test_that("Malliavin_European_Greeks is correct", {
         volatility = volatility,
         dividend_yield = 0,
         payoff = payoff,
-        greek = greek
+        greek = Greeks
       )
 
-    error[i] <-
-      min(abs(Malliavin_Value - Exact_Value)/(abs(Malliavin_Value + epsilon)),
-          abs(Malliavin_Value - Exact_Value))
+    error[i, ] <-
+      pmin(abs(Malliavin_Value - Exact_Value)/(abs(Malliavin_Value + epsilon)),
+           abs(Malliavin_Value - Exact_Value))
 
   }
 
-  expect(max(error) < 0.01)
+  # "asset_or_nothing_call and asset_or_nothing_put payoff-functions have much
+  # more variance
+  expect(max(error[1:4]) < 0.01 && max(error[5:6]) < 0.1,
+         "The results of Malliavin_European_Greeks() are not close enough to
+         BS_European_Greeks()")
+
   expect_error(Malliavin_European_Greeks(model = "whatever_model"))
 
   # Check, whether custom payoff function works
@@ -69,6 +72,6 @@ test_that("Malliavin_European_Greeks is correct", {
     sum(abs(Malliavin_European_Greeks(payoff = call_function) -
               Malliavin_European_Greeks(payoff = "call")))
 
-  expect(abs(diff) < 1e-7)
+  expect(abs(diff) < 1e-7, "Custom payoff function does not seem to work")
 
 })
